pub struct DeleteBaselineResponse {
pub deleted: bool,
pub id: String,
pub benchmark: String,
pub version: String,
pub deleted_at: DateTime<Utc>,
}Expand description
Response for baseline deletion.
Fields
deleted: boolid: Stringbenchmark: Stringversion: Stringdeleted_at: DateTime<Utc>Trait Implementations
Sourceimpl Clone for DeleteBaselineResponse
impl Clone for DeleteBaselineResponse
Sourcefn clone(&self) -> DeleteBaselineResponse
fn clone(&self) -> DeleteBaselineResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DeleteBaselineResponse
impl Debug for DeleteBaselineResponse
Sourceimpl<'de> Deserialize<'de> for DeleteBaselineResponse
impl<'de> Deserialize<'de> for DeleteBaselineResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for DeleteBaselineResponse
impl JsonSchema for DeleteBaselineResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for DeleteBaselineResponse
impl RefUnwindSafe for DeleteBaselineResponse
impl Send for DeleteBaselineResponse
impl Sync for DeleteBaselineResponse
impl Unpin for DeleteBaselineResponse
impl UnsafeUnpin for DeleteBaselineResponse
impl UnwindSafe for DeleteBaselineResponse