pub struct ListFleetAlertsResponse {
pub alerts: Vec<FleetAlert>,
}Expand description
Response for listing fleet alerts.
Fields
alerts: Vec<FleetAlert>Trait Implementations
Sourceimpl Clone for ListFleetAlertsResponse
impl Clone for ListFleetAlertsResponse
Sourcefn clone(&self) -> ListFleetAlertsResponse
fn clone(&self) -> ListFleetAlertsResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ListFleetAlertsResponse
impl Debug for ListFleetAlertsResponse
Sourceimpl<'de> Deserialize<'de> for ListFleetAlertsResponse
impl<'de> Deserialize<'de> for ListFleetAlertsResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ListFleetAlertsResponse
impl JsonSchema for ListFleetAlertsResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ListFleetAlertsResponse
impl RefUnwindSafe for ListFleetAlertsResponse
impl Send for ListFleetAlertsResponse
impl Sync for ListFleetAlertsResponse
impl Unpin for ListFleetAlertsResponse
impl UnsafeUnpin for ListFleetAlertsResponse
impl UnwindSafe for ListFleetAlertsResponse