pub struct PromoteBaselineRequest {
pub from_version: String,
pub to_version: String,
pub git_ref: Option<String>,
pub git_sha: Option<String>,
pub tags: Vec<String>,
pub normalize: bool,
}Expand description
Request for baseline promotion.
Fields
from_version: Stringto_version: Stringgit_ref: Option<String>git_sha: Option<String>normalize: boolTrait Implementations
Sourceimpl Clone for PromoteBaselineRequest
impl Clone for PromoteBaselineRequest
Sourcefn clone(&self) -> PromoteBaselineRequest
fn clone(&self) -> PromoteBaselineRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PromoteBaselineRequest
impl Debug for PromoteBaselineRequest
Sourceimpl<'de> Deserialize<'de> for PromoteBaselineRequest
impl<'de> Deserialize<'de> for PromoteBaselineRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PromoteBaselineRequest
impl JsonSchema for PromoteBaselineRequest
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for PromoteBaselineRequest
impl RefUnwindSafe for PromoteBaselineRequest
impl Send for PromoteBaselineRequest
impl Sync for PromoteBaselineRequest
impl Unpin for PromoteBaselineRequest
impl UnsafeUnpin for PromoteBaselineRequest
impl UnwindSafe for PromoteBaselineRequest