pub struct PromoteBaselineResponse {
pub id: String,
pub benchmark: String,
pub version: String,
pub promoted_from: String,
pub promoted_at: DateTime<Utc>,
pub created_at: DateTime<Utc>,
}Expand description
Response for baseline promotion.
Fields
id: Stringbenchmark: Stringversion: Stringpromoted_from: Stringpromoted_at: DateTime<Utc>created_at: DateTime<Utc>Trait Implementations
Sourceimpl Clone for PromoteBaselineResponse
impl Clone for PromoteBaselineResponse
Sourcefn clone(&self) -> PromoteBaselineResponse
fn clone(&self) -> PromoteBaselineResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PromoteBaselineResponse
impl Debug for PromoteBaselineResponse
Sourceimpl<'de> Deserialize<'de> for PromoteBaselineResponse
impl<'de> Deserialize<'de> for PromoteBaselineResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PromoteBaselineResponse
impl JsonSchema for PromoteBaselineResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for PromoteBaselineResponse
impl RefUnwindSafe for PromoteBaselineResponse
impl Send for PromoteBaselineResponse
impl Sync for PromoteBaselineResponse
impl Unpin for PromoteBaselineResponse
impl UnsafeUnpin for PromoteBaselineResponse
impl UnwindSafe for PromoteBaselineResponse